@@ -4,4 +4,5 @@ srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
 autoreconf -i -f \
-  && glib-gettextize -c -f
+  && glib-gettextize -c -f \
+  && intltoolize -c -f --automake
