@@ -615,7 +615,7 @@ main (int argc, char **argv)
 		g_object_unref (synaptics);
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
 					_("GSynaptics couldn't initialize.\n"
-			      		"You have to set 'SHMconfig' 'true' in xorg.conf of XF86Config to use GSynaptics\n"));
+			      		"You have to set 'SHMConfig' 'true' in xorg.conf or XF86Config to use GSynaptics\n"));
 		gtk_dialog_run (GTK_DIALOG(dialog));
 		gtk_widget_destroy (dialog);
 		
